#
# spec file for package abcm2ps
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2007 by Edgar Aichinger
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           abcm2ps
Version:        8.14.4
Release:        1.1
Summary:        A program to typeset abc tunes into Postscript
License:        GPL-2.0-or-later
Group:          Productivity/Publishing/Other
Summary(de):    Ein Werkzeug um ABC-Notationen in Postscript zu drucken
URL:            https://github.com/leesavide/abcm2ps/
Source0:        https://github.com/leesavide/abcm2ps/archive/v%{version}.tar.gz
Source1:        italian.fmt
Source2:        deco-guitar.fmt
Source3:        deco-marks.fmt
Source4:        renaissance.fmt
Source5:        thinlines.fmt
BuildRequires:  pkgconfig
# for rst2man
BuildRequires:  python3-docutils
# for rendering non-latin characters in Postscript output
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(pangocairo)

%description
abcm2ps is a package which converts music tunes from ABC format to
PostScript. Based on abc2ps version 1.2.5, it was developed mainly to print
barock organ scores which have independent voices played on one or many
keyboards and a pedal board. abcm2ps introduces many extensions to the ABC
language that make it suitable for classical music.

%prep
%setup -q
mv config.h.in config.h.sed
sed "s/\/\/#define A4_FORMAT/#define A4_FORMAT/" config.h.sed > config.h.in

%build
%configure
make %{?_smp_mflags}

%install
%make_install
# remove documentation and examples from wrong install path
rm -rf %{buildroot}/%{_datadir}/doc

%files
%license COPYING
%doc README.md *.abc sample3.eps
%{_bindir}/*
%{_datadir}/%{name}
%{_mandir}/man1/%{name}*

%changelog
* Mon Mar 18 2019 mvetter@suse.com
- Update to 8.14.4:
  * program loop when P: on beamed note at end of line and %%%%breakoneoln 0
  * crash/loop when slur between note and grace note and other slurs later
* Mon Mar 11 2019 mvetter@suse.com
- Update to 8.14.3:
  * erroneous double '8va's on a same staff when set on combined notes/rests
  * don't put two '8va's on the same staff
  * loss of %%%%sep since previous version
* Sat Dec 22 2018 Michael Vetter <mvetter@suse.com>
- Update to 8.14.2:
  * !8va! must be above the staff
  * crash when SVG output and call to an unknown symbol in PS sequence
  * crash when no note in voice overlay
  * crash when SVG output and 'F' is not a font name in a PS sequence
  * crash when only one bar in a voice and no symbol in a second voice
  * possible crashes when bad definition of special decorations
  * crash on decoration type 7 without start/stop
  * crash on decoration type 5 without start/stop
  * crash when unterminated decoration in U:
  * crash when random character greater than 128 in a s: line
  * bad test of font encoding
  * read access outside of array when exact memory allocation of w:
  * read access outside of array on small line starting with %%%%
  * fixes from Debian (Makefile/configure/INSTALL)
* Mon Nov 19 2018 mvetter@suse.com
- Update to 8.14.1:
  * bad definition of the music font (@font-face[1])
  * bad error when --pango 2 in command line and SVG output
  * bad beams when notes on 2 staves and %%%%flatbeams
  * error in SVG output when color setting since version v8.14.0
  * code revert: use pango only when needed
  * crash in 'make install' when no 'rst2man' in the shell PATH
* Mon Sep 24 2018 Jan Engelhardt <jengelh@inai.de>
- Fix some grammar issues in descriptions.
- Use %%configure macro.
* Fri Sep 21 2018 Edgar Aichinger <edogawa@aon.at>
- more work on spec to enable A4 paper format and use pango for non-latin characters in PS output
- use make install target instead of custom commands in specfile
* Thu Sep 13 2018 Edgar Aichinger <edogawa@aon.at>
- some minor specfile tweaks to reduce rpmlint warnings
* Wed Sep 12 2018 mvetter@suse.com
- Update to 8.14.0:
  * better handling of fonts when pango
  * bad transposition when chord symbols separated by ';'
  * always use pango when available
  * Use CSS shorthand file description for SVG output
  build:
  * Split clean targets according to the GNU guidelines
  * Install documentation into prefix/share/doc instead of prefix/doc
  * Install the examples in a separate documentation directory
  documentation:
  * add man page
- Use github URL in source field
- Clean up spec file with spec-cleaner
- Clean up spec file according to rpmlint warnings
- Use %%license tag for COPYING file
- Dont install INSTALL file
* Fri Jan 12 2018 edogawa@aon.at
- updated to version 8.13.18
- sources are on github now, changed specfile accordingly
* Tue May 21 2013 edogawa@aon.at
- updated to version 6.6.22
* Thu Aug  5 2010 edogawa@aon.at
- updated to version 5.9.15
- updated/added format files from abcplus page
* Fri Dec 11 2009 edogawa@aon.at
- updated to version 5.9.7
* Tue Oct 20 2009 edogawa@aon.at
- updated to version 5.9.6
* Wed Aug 12 2009 edogawa@aon.at
- updated to version 5.9.5
* Fri Apr 24 2009 edogawa@aon.at
- updated to version 5.9.4
* Sun Jul  8 2007 edogawa@aon.at
- updated to version 4.12.30
* Thu Jan  4 2007 christian@links2linux.de
- added 3 .fmt extensions
* Wed Jan  3 2007 christian@links2linux.de
- taken from "original" src.rpm from the project homepage
  rewritten for packman
- initial version 4.12.27
